<?php

namespace App\Http\Controllers;

use App\Helpers;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\Log;
use Illuminate\View\View;
use Psr\Log\LoggerInterface;
use tgMdk\dto\CardAuthorizeRequestDto;
use tgMdk\dto\CardAuthorizeResponseDto;
use tgMdk\TGMDK_Logger;
use tgMdk\TGMDK_Transaction;

class CardController extends Controller
{
    public function index(): View
    {
        return view('card.index')->with(
            [
                'tokenApiKey' => Config::get('sample_setting.token.token_api_key'),
                "amount" => "100",
                "orderId" => Helpers::generateOrderId()
            ]);
    }

    public function cardAuthorize(Request $request): View|RedirectResponse
    {

        $logger = Log::channel('tgmdk')->getLogger();
        if ($logger instanceof LoggerInterface) {
            TGMDK_Logger::setLogger($logger);
        }

        $request_data = new CardAuthorizeRequestDto();
        $request_data->setAmount($request->request->get("amount"));
        $request_data->setOrderId($request->request->get("orderId"));
        $request_data->setToken($request->request->get("token"));
        $request_data->setWithCapture($request->request->get("withCapture"));

        $request_data->setJpo(
            Helpers::generateJpo($request->request->get("jpo1"), $request->request->get("jpo2"))
        );


        /*
         * 設定ファイルのパスを手動で指定する場合は以下のようにパスを指定してTGMDK_Configクラスのインスタンス生成をしておく
         * TGMDK_Config::getInstance("/home/test/laravel_sample/config/3GPSMDK.properties");
         */

        $transaction = new TGMDK_Transaction();
        $response_data = $transaction->execute($request_data);

        /*
         * マーチャントIDとマーチャント認証鍵を動的に設定する場合はexecuteメソッドの第2引数に以下のようにセットする
         * $props["merchant_ccid"] = "Set MerchantCCID here";
         * $props["merchant_secret_key"] = "Set MerchantSecretKey here";
         * $response_data = $transaction->execute($request_data, $props);
         */

        if ($response_data instanceof CardAuthorizeResponseDto) {
            $request->session()->put($request->request->get("orderId"), $response_data);
            return redirect()->action([CardController::class, "authorizeResult"], ['orderId' => $request->request->get("orderId")]);
        }

        return view('card/index')->with(
            [
                'tokenApiKey' => Config::get('sample_setting.token.token_api_key'),
                'amount' => $request->request->get("amount")
            ]);

    }

    public function authorizeResult($orderId): View
    {
        $response_data = session($orderId);
        if ($response_data instanceof CardAuthorizeResponseDto) {
            return view('card/result')->with([
                'mstatus' => $response_data->getMstatus(),
                'vResultCode' => $response_data->getVResultCode(),
                'mErrMsg' => $response_data->getMerrMsg(),
                'orderId' => $response_data->getOrderId(),
                'resAuthCode' => $response_data->getResAuthCode(),
                'reqCardNumber' => $response_data->getReqCardNumber()
            ]);
        } else {
            return view('card/result')->with([
                'mstatus' => null, 'vResultCode' => null, 'mErrMsg' => null, 'orderId' => null, 'resAuthCode' => null,
                'reqCardNumber' => null, 'message' => "error!"
            ]);
        }
    }


}
